/**** IDENTIFICATION ***************************************************/
/*                                                                     */
/*    Project: FLASHCRAFT FUNKBOARD         Autor : Florian Scherb     */
/*    Module : main                         Source: FUNKBOARD.c        */
/*                                                                     */
/*                                                                     */
/* == FUNCTIONAL DESCRIPTION OF MODULE =============================== */
/*                                                                     */
/*    This module contains the main function and basic declarations of */
/*    the whole project.                                               */
/*                                                                     */
/* == FUNCTIONAL DESCRIPTION OF THE FUNKBOARD PROJECT ================ */
/*                                                                     */
/*    The "FLASHCRAFT Funkboard" is a small radio communication unit   */
/*    that makes it possible to communicate very easily with other     */
/*    units of the same type.                                          */
/*    The "FLASHCRAFT Funkboard" contains a RFM12 tranceiver module,   */
/*    a ATmega32 and some other periphery. The board behaves           */
/*    like a blackbox to the outside world. All difficult routines     */
/*    and instructions are not visible for the user.                   */
/*    It is also possible to configure the module to the requirements  */
/*    of the user. The user can make changes to the FIFO buffers, the  */
/*    the interface parameters and to the RFM12 itselfs.               */
/*                                                                     */
/*                                                                     */
/* == FUNCTIONAL DESCRIPTION OF THE SOURCE CODE ====================== */
/*                                                                     */
/*    This is the source code of the "FLASHCRAFT Funkboard" project.   */
/*    To ensure that you have the latest version of this source code   */
/*    compare the history remark in this file with the history remark  */
/*    on the project site www.flashcraft.de                            */
/*                                                                     */
/*    This code was built and compiled with AVR Studio version 413     */
/*    Built 528. To modify the code easily please be sure to use the   */
/*    latest version of AVR Studio.                                    */
/*                                                                     */
/* == COPYRIGHT AND LICENCE ========================================== */
/*                                                                     */
/*    The whole code of this project was created by Florian Scherb.    */
/*    If you want to use this code in non-commercial projects you are  */
/*    free to copy and modify the code, but do not delete the history  */
/*    remark.                                                          */
/*    It is prohibited to use this code in commercial projects! If you */
/*    want to use this code in commmercial projects please contact the */
/*    author, Florian Scherb.                                          */
/*    Visit www.flashcraft.de for more information.                    */                                                           
/*                                                                     */
/*                                                                     */
/* == HISTORY ======================================================== */
/*                                                                     */
/*    Name            Date          Action                             */
/* ------------------------------------------------------------------- */
/*    F.Scherb        16.11.08		Updated receiving/transmitting     */
/*    F.Scherb        29.09.08		Finished version 1.0.0             */
/*    F.Scherb        16.08.08		The project starts...              */
/*                                                                     */
/* == IMPORTANT ====================================================== */
/*                                                                     */
/*    Name            Date          Action                             */
/* ------------------------------------------------------------------- */
/*    F.Scherb        29.09.08		SC and LBF  are not used           */
/*    F.Scherb        22.10.08      I2C and SPI are not implemented!   */
/*    F.Scherb        30.11.08      New checksum implemented           */
/*                                                                     */
/*                                                                     */
/***********************************************************************/


/* == DEFINITION OF LOCAL SYNONYMS =================================== */
/*                                                                     */

/* == EXTERNALS ====================================================== */
/*                                                                     */
#include <avr/io.h>				// Basic input/output definitions
#include <util/delay.h>			// Delay time definitions
#include <avr/interrupt.h>		// Interrupt definitions
#include <math.h>				// Mathematics
#include <inttypes.h>			// Types
#include <avr/sleep.h>			// Sleep mode
#include "headers/defines.h"	// Basic defines 
#include "headers/global.h"		// Global declarations
#include "uart/uart.h"			// UART

/* == EXTERNAL C-Files (must also be included in the project) ======== */
/*                                                                     */
/* configuration.c         <= Includes all configuration options       */
/* error_handler.c         <= Includes the error handler               */
/* i2cslave.c			   <= Library for the I2C mode				   */
/* initialize.d            <= Includes the initializing sequence       */
/* interrupts.c            <= Includes all interrupts that are used    */
/* leds.c                  <= Controls the LEDs                        */
/* received_data.c         <= Handles the received data from the RFM12 */
/* rf12.c                  <= Includes all RFM12-based functions       */
/* uart.c				   <= Contains the UART Library                */
/* uart_bitrate.c          <= Extended UART functions                  */
/* status_register.c	   <= Contains the status register             */

/* == GLOBAL DATA ==================================================== */
/*                                                                     */

/* == DEFINITION OF LOCAL TYPES ====================================== */
/*                                                                     */

/* == FUNCTION PROTOTYPES ============================================ */
/*                                                                     */

/* == FUNCTION main ================================================== */
/*                                                                     */
/*    This function controls the whole program                         */ 
/*    It mainly consists of a initializing sequence and a loop         */
/*    sequence. All functions and interrupts are called from other     */
/*    c.Files, so please have a look on the list at the top of this    */
/*    file.															   */
/*                                                                     */
/* -- PARAMETERS ----------------------------------------------------- */
/*                                                                     */
/*    none                                              			   */
/*                                                                     */
/* -- RETURN VALUE --------------------------------------------------- */
/*                                                                     */
/*    none (never executed)  										   */
/*                                                                     */
/***********************************************************************/

int main(void)
{
	initialize();				// Initialize the program 12049,38 us

    for (;;)
    {
		radio_receive_data();	// function to receive new data via the RFM12 module
		is_data_available();	// function to transmit data via the RFM12 module
    }

	return 0;					// Return statement, never executed
}

/** END OF MODULE ******************************************************/

