/**** IDENTIFICATION ***************************************************/
/*                                                                     */
/*    Project: Funkmodul                    Autor : Florian Scherb     */
/*    Module : global                       Source: global.c           */
/*                                                                     */
/*                                                                     */
/* == FUNCTIONAL DESCRIPTION OF MODULE =============================== */
/*                                                                     */
/*    This module contains all global data, function prototypes and    */
/*    global synonyms                                                  */
/*                                                                     */
/*                                                                     */
/***********************************************************************/


/*** DEFINITION OF GLOBAL TYPES ****************************************/
typedef unsigned char		 U_INT8;
typedef unsigned short int	 U_INT16;
typedef unsigned long int	 U_INT32;
typedef signed char			 S_INT8;
typedef signed short int	 S_INT16;
typedef signed long int		 S_INT32;

/*** DEFINITION OF GLOBAL ENUMS ****************************************/
typedef enum {FALSE, TRUE} BOOL; 				// BOOL
typedef enum {BAUD1200,BAUD2400,BAUD4800,BAUD9600,BAUD19200,BAUD38400,BAUD57600,BAUD69000,BAUD115200} BAUDRATE;// Definition of internal Baudrate
typedef enum {NO_ERROR, FRAMEERROR, OVERRUNERROR, BUFFEROVERFLOW, RADIO_DATANOTVALID, RADIO_INBUFFEROVERFLOW, RADIO_OUTBUFFEROVERFLOW, TRANSMIT_TIMEOUT, TRANSMIT_ERROR, TRANSMIT_NACK, TRANSMIT_SOMETRY, DUMMY} ERRORCODE;	// Error code to analyze errors

/*** GLOBAL VARIABLES **************************************************/

// Configuration variables
extern unsigned char gbl_config_channel;		// Channel [Nr]: 0...38 (default 5)
extern unsigned char gbl_config_baud;			// Baudrate [Baud]: 0=1200, 1=2400, 2=4800, 3=9600, 4=19200, 5=38400 (default 3=9600)
extern unsigned char gbl_config_lnagain;		// LNA Gain [dBm]: 0=0dBm, 1=-6dBm, 2=-14dBm, 3=-20dBm (default 0=0dBm)
extern unsigned char gbl_config_rssi;			// RSSI Thres [dBm]: 0=-103dBm, 1=-97dBm, 2=-91dBm, 3=-85dBm, 4=-79dBm, 5=-73dBm, 6=-67dBm, 7=-61dBm (default 0=-103dBm)
extern unsigned char gbl_config_bandwidth;		// Bandwidth [kHz]: 0=400kHz, 1=340kHz, 2=270kHz, 3=200kHz, 4=134kHz, 5=67kHz (default 4=134kHz)
extern unsigned char gbl_config_dqd;			// DQD [Value]: 0...7 (default 3)
extern unsigned char gbl_config_power;			// Power [Value]: 0...7 (default 7)
extern unsigned char gbl_config_startchar;		// Start Character [Value]: 0...0xFF (default '#' or 0x23)
extern unsigned char gbl_config_uartbaud;		// External UART-Baudrate [Baud]: 0=1200, 1=2400, 2=4800, 3=9600, 4=14400, 5=19200, 6=28800, 7=38400, 8=57600, 9=76800, 10=115200, 11=230400, 12=250000 (default 3=9600)
extern unsigned char gbl_config_pollmode;		// Poll mode [Value]: 0=Poll mode disabled, 1=Poll mode active (default: 0=Poll mode disabled)
extern unsigned char gbl_config_fifoinput;		// Size of the FIFO buffer for received chars [Byte]: 4...255 (default: 16)
extern unsigned char gbl_config_fifooutput;		// Size of the FIFO buffer for transfered chars [Byte]: 4...255 (default: 16)
extern unsigned char gbl_config_clkfrequ;  		// Frequency of the external clock ouput pin: 0=10MHz, 1=5MHz, 2=3,33MHz, 3=2,5MHz, 4=2MHz, 5=1,66MHz, 6=1,25MHz, 7=1MHz
extern unsigned char gbl_config_max;			// Settings MAX3221: 0=On (and Autoshutdown), 1=Off, (default 0=On)
extern unsigned char gbl_config_ledsactive;	    // State of the LEDs: 0=Normal Operation, 1=All LEDs are off
extern unsigned char gbl_config_id_own;			// Identification number of the board: Standard = 0, do not use 0xAA!!
extern unsigned char gbl_config_id_target;  	// Identification number of the target or receiver board
extern U_INT16       gbl_config_status;			// The status register is initialized in the initialize.c

// Configuration variables for the EEPROM
extern unsigned char ee_config_channel    EEMEM;
extern unsigned char ee_config_baud       EEMEM;
extern unsigned char ee_config_lnagain    EEMEM;
extern unsigned char ee_config_rssi       EEMEM;
extern unsigned char ee_config_bandwidth  EEMEM;
extern unsigned char ee_config_dqd        EEMEM;
extern unsigned char ee_config_power      EEMEM;
extern unsigned char ee_config_startchar  EEMEM;
extern unsigned char ee_config_uartbaud   EEMEM;
extern unsigned char ee_config_pollmode   EEMEM;
extern unsigned char ee_config_uartactive EEMEM;
extern unsigned char ee_config_i2cactive  EEMEM;
extern unsigned char ee_config_spiactive  EEMEM;
extern unsigned char ee_config_fifoinput  EEMEM;	
extern unsigned char ee_config_fifooutput EEMEM;
extern unsigned char ee_config_ledsactive EEMEM;
extern unsigned char ee_config_clkfrequ   EEMEM;
extern unsigned char ee_config_max        EEMEM;
extern unsigned char ee_config_id_own 	  EEMEM;

// Variables for received data via UART, SPI or I2C
extern unsigned char gbl_rcintcounter;						// Do not change this value, counter variable for UART interrupt
extern unsigned char gbl_dataavail_type;					// Indicates what kind of data is available: 0=no data available, 1=configuration data, 2=transmit/receive data
extern unsigned char gbl_receive_buffer[MBF];				// Holds the last received bytes from UART/I2C/SPI (only in configuration mode)
extern unsigned char gbl_uart_receive_buffer[MBF]; 		 	// Holds the actual received byte from UART
extern unsigned char gbl_spi_receive_buffer[MBF];    		// Holds the actual received byte from SPI
extern unsigned char gbl_i2c_receive_buffer[MBF];  			// Holds the actual received byte from I2C
extern unsigned char gbl_select_interface;	   				// 0=No interface selected, 1=UART, 2=I2C, 3=SPI

extern volatile unsigned char gbl_INT_Timer2_Counter_Max;	// Maximum cycles for the timer2 before the code in the interrupt is executed
extern volatile unsigned char gbl_INT_Timer2_Counter;   	// Counter for the timer2, do not change this value
extern volatile unsigned char gbl_INT_Timer0_Counter;		// Do not change this value, counter variable for timer0
extern volatile unsigned char gbl_INT_Timer0_Timeout;		// Flag for timeout: 0 = No Timeout, 1 = Timeout
extern volatile unsigned char gbl_INT_Timer1_State;			// Current state of the Timer1: 0=Nothing,1=RCC-LED,2=ACK-Timeout
extern volatile unsigned char gbl_INT_Timer1_Timeout;		// Flag for timeout: 0 = No Timeout, 1 = Timeout

// Variables for radio received / transfered data
extern unsigned char gbl_radio_input_fifobuffer[MBF];		// Second input buffer 
extern unsigned char gbl_radio_input_muxbuffer[10][MBF];	// The input FIFO buffer
extern unsigned char gbl_radio_input_charnumber[10];		// In variable char length mode the length of all chars in the FIFO input buffer is stored here
extern volatile unsigned char gbl_radio_input_locnextfreepack;		// Counter for the input FIFO buffer to identify the next free position, do not change!

extern unsigned char gbl_radio_output_muxack[10];			// The output FIFO acknowledge buffer
extern unsigned char gbl_radio_output_muxrec[10];			// The output FIFO receiver buffer
extern unsigned char gbl_radio_output_muxbuffer[10][MBF];	// The output FIFO buffer
extern unsigned char gbl_radio_output_fifobuffer[MBF];		// Second output buffer
extern unsigned char gbl_radio_output_locnextfreepack;		// Counter for the output FIFO buffer to identify the next free position, do not change!
extern unsigned char gbl_radio_output_muxnbr[10];			// In variable char length mode the length of all chars in the FIFO output buffer is stored here

extern unsigned char gbl_radio_recack;						// Flag to indicate whether the transmitter wishes a ACK or not: 0=no ack, 1=ack
extern unsigned char gbl_radio_sendack; 					// Flag to indicate whether the user wishes a ACK or not: 0=no ack, 1=ack
extern unsigned char gbl_radio_input_bufferoverflow;		// Flag to indicate the overflow status of the in-buffer (0=No overflow, 1=Overflow)
extern unsigned char gbl_radio_output_bufferoverflow;		// Flag to indicate the overflow status of the out-buffer (0=No overflow, 1=Overflow)
extern unsigned char gbl_radio_output_bufferready;			// Flag to indicate whether the programm is ready to receive the next byte (0) or not (1)

// Variables for RFM12 module
extern volatile unsigned char gbl_RX_buffer;				// Flag for the RX buffer: 0 = buffer empty, 1 = buffer full	
extern unsigned char gbl_rxdata_errormessage;				// This flag indicates in the rf12_rxdata function if a error message
															// is reported (flag=1) or not (flag=0)

/*** EXTERNAL FUNCTIONS: rf12.c ***************************************/
extern void rf12_init(void);
extern void rf12_sleep(void);
extern void rf12_setclk(unsigned char clkfrequency);
extern void rf12_wakeup(void);
extern void rf12_setchannel(unsigned char channel);
extern void rf12_setbaudrate(BAUDRATE baud);
extern void rf12_setpower(unsigned char power);
extern void rf12_setreccontrol(U_INT16 bandwidth, signed char gain, signed char rssi_threshold);
extern void rf12_setdqdreport(unsigned char dqd);
extern void rf12_ready(void);
extern void rf12_txdata(unsigned char *data, unsigned char number, unsigned char startchar, unsigned char own_id, unsigned char target_id, unsigned char acknowledge);
extern void rf12_txack(unsigned char state, unsigned char startchar);
extern void rf12_enabletimeout(void);
extern void rf12_disabletimeout(void);
extern unsigned char rf12_rxack(unsigned char startchar);
extern unsigned char rf12_rxdata(unsigned char *data, unsigned char startchar, unsigned char *datastringlen);
extern unsigned short rf12_trans(unsigned short wert);
extern void configuration_fifoinputclear(void);
extern void configuration_fifooutputclear(void);
extern unsigned char rf12_acktimeout(void);

/*** EXTERNAL FUNCTIONS: configuration.c ******************************/
extern void configuration_main(U_INT16 received_dword);
extern void configuration_sleep(void);
extern void configuration_fastinitialize(void);
extern void configuration_initialize(void);
extern void configuration_channel(void);
extern void configuration_baud(void);
extern void configuration_dqd(void);
extern void configuration_power(void);
extern void configuration_rssi_bandwidth_lnagain(void);
extern void configuration_resetsettings(void);
extern void configuration_saveineeprom(void);
extern void configuration_loadfromeeprom(void);
extern void configuration_resetboard(void);
extern void configuration_atmegabaudrate(void);
extern void configuration_status(unsigned char send_status);
extern void configuration_sendreceiveddata(void);
extern void configuration_version(void);
extern void configuration_maxrs232(void);

/** EXTERNAL FUNCTIONS: leds.c ****************************************/
extern U_INT8 set_leds(volatile U_INT8 lednr, volatile U_INT8 status);
extern void toggle_leds(volatile U_INT8 lednr);

/** EXTERNAL FUNCTIONS: initialize.c **********************************/
extern void initialize(void);

/** EXTERNAL FUNCTIONS: interrupts.c **********************************/
extern void INT_UART_ReceiveComplete(void);
extern void handle_outputbuffer(unsigned char *receive_buffer_p, unsigned char len);
extern void TIMER2_COMPARE_INTERRUPT(void);

/** EXTERNAL FUNCTIONS: error_handler.c ******************************/
extern unsigned char error_handler(ERRORCODE errormsg);

/** EXTERNAL FUNCTIONS: received_data.c ******************************/
extern void radio_transmit_data(unsigned char *data, unsigned char startchar, unsigned char charlength, unsigned char target_id, unsigned char acknowledge);
extern void is_data_available(void);
extern void radio_receive_data(void);

/** EXTERNAL FUNCTIONS: uart_bitrate.c *******************************/
extern unsigned char compute_bitrate(unsigned char baudrate);



