/**** IDENTIFICATION ***************************************************/
/*                                                                     */
/*    Project: Reflowofen                    Autor : Florian Scherb    */
/*    Module : leds                          Source: leds.c            */
/*                                                                     */
/*                                                                     */
/* == FUNCTIONAL DESCRIPTION OF MODULE =============================== */
/*                                                                     */
/*    This module contains functions to control the leds.              */
/*                                                                     */
/***********************************************************************/

/* == EXTERNALS ====================================================== */
/*                                                                     */
#include "../headers/defines.h"
#include "../headers/global.h"
#include <avr/io.h>

/* == FUNCTION PROTOTYPES ============================================ */
/*                                                                     */


/* == FUNCTION set_leds ============================================== */
/*                                                                     */
/*    This function turns the leds on or off                           */
/*                                                                     */
/* -- PARAMETERS ----------------------------------------------------- */
/*                                                                     */
/*    U_INT8 lednr  - LED number, ranges from LED1 to LED3             */
/*    U_INT8 status - Status of the LED, could be ON or OFF            */
/*                                                                     */
/* -- RETURN VALUE --------------------------------------------------- */
/*                                                                     */
/*    U_INT8   => 1  valid, one LED changes or remains in its state    */
/*             => 0  not valid, invalid LED number                     */
/*                                                                     */
/***********************************************************************/
U_INT8 set_leds(volatile U_INT8 lednr, volatile U_INT8 status)
{
	
    if(lednr == LED_POWERGOOD)
    {
		if(status==LED_ON)
	    	LED_PORT_POWERGOOD |=  (1<<LED_PNR_POWERGOOD);
		else if(status==LED_OFF)
			LED_PORT_POWERGOOD &= ~(1<<LED_PNR_POWERGOOD);
		
		return 1;		
    }
   if(lednr == LED_RECEIVING)
    {
		if(status==LED_ON)
	    	LED_PORT_RECEIVING |=  (1<<LED_PNR_RECEIVING);
		else if(status==LED_OFF)
			LED_PORT_RECEIVING &= ~(1<<LED_PNR_RECEIVING);
		
		return 1;		
    }
   if(lednr == LED_TRANSMITT)
    {
		if(status==LED_ON)
	    	LED_PORT_TRANSMITT |=  (1<<LED_PNR_TRANSMITT);
		else if(status==LED_OFF)
			LED_PORT_TRANSMITT &= ~(1<<LED_PNR_TRANSMITT);
		
		return 1;		
    }
	
	return 0;
}


/* == FUNCTION toggle_leds =========================================== */
/*                                                                     */
/*    This function toggles a LED between the on and off state         */
/*                                                                     */
/* -- PARAMETERS ----------------------------------------------------- */
/*                                                                     */
/*    U_INT8 lednr  - LED number, ranges from LED1 to LED3             */
/*                                                                     */
/* -- RETURN VALUE --------------------------------------------------- */
/*                                                                     */
/*    none                                                             */
/*                                                                     */
/***********************************************************************/
void toggle_leds(volatile U_INT8 lednr)
{
    if(lednr == LED_POWERGOOD)
    {
	 	if(   LED_PIN_POWERGOOD & (1<<LED_IPN_POWERGOOD)  )
    	   set_leds(LED_POWERGOOD,LED_OFF);
		else
		   set_leds(LED_POWERGOOD,LED_ON);
    }
   if(lednr == LED_RECEIVING)
    {
	 	if(   LED_PIN_RECEIVING & (1<<LED_IPN_RECEIVING)  )
    	   set_leds(LED_RECEIVING,LED_OFF);
		else
		   set_leds(LED_RECEIVING,LED_ON);		
    }
   if(lednr == LED_TRANSMITT)
    {
	 	if(   LED_PIN_TRANSMITT & (1<<LED_IPN_TRANSMITT)  )
    	   set_leds(LED_TRANSMITT,LED_OFF);
		else
		   set_leds(LED_TRANSMITT,LED_ON);		
    }




}

/** END OF MODULE ******************************************************/
